@@ -17,6 +17,7 @@ from .util import has_yaml, path_type, safe_dump_json, safe_dump_yaml, safe_read
 
 path_type_w_stdin = partial(path_type, allow_stdin=True)
 
+
 def get_args():
     parser = argparse.ArgumentParser(
         prog=pathlib.Path(sys.argv[0]).name,
@@ -50,7 +51,15 @@ def get_args():
     )
 
     parser.add_argument(
-        'input',
+        "--array-strategy",
+        action="store",
+        choices=["replace", "extend", "merge"],
+        default="replace",
+        help='Set merge strategy for arrays. One of "replace", "extend", or "merge". Defaults to "replace"',
+    )
+
+    parser.add_argument(
+        "input",
         nargs="+",
         type=path_type_w_stdin,
         default=[],
@@ -61,7 +70,7 @@ def get_args():
         "-o",
         "--output",
         action="store",
-        default='/dev/stdout',
+        default="/dev/stdout",
         type=path_type,
         help="Write merged output to this path.",
     )
@@ -81,6 +90,7 @@ def get_args():
 
     return args
 
+
 def cli():
     args = get_args()
     config = load_config(args)
@@ -98,7 +108,9 @@ def cli():
             log.error(f"Failed to read input file {path}")
             sys.exit(1)
         try:
-            merged = recurse_update(merged, resolve_refs(path, doc))
+            merged = recurse_update(
+                merged, resolve_refs(path, doc), array_strat=config.array_strategy
+            )
         except JamError as e:
             log.exception("Unhandled Error")
             sys.exit(1)
